<?php

namespace theme_unige\output;

defined('MOODLE_INTERNAL') || die;

use html_writer;
use moodle_url;
use stdClass;
use context_header;
use action_menu_filler;
use action_menu;
use pix_icon;
use action_menu_link_secondary;
use context_system;
use context_course;
use coursecat;
use navigation_node;
use core_text;

class core_renderer extends \theme_boost\output\core_renderer {

    /**
     * Wrapper for header elements.
     *
     * @return string HTML to display the main header.
     */
    public function full_header() {
        global $PAGE;

        $header = new stdClass();
        $header->settingsmenu = $this->course_edit_mode_button();
        if ($this->page->pagelayout == "frontpage"){
            $header->settingsmenu .= $this->add_block_button_index_admin();
        }
        $header->settingsmenu .= $this->context_header_settings_menu();
        if ($this->page->pagelayout == "mydashboard") {
            $header->settingsmenu = $this->create_course_button();
            $header->settingsmenu .= $this->add_block_button_my_courses();
            $header->settingsmenu .= $this->page_heading_button();
        }
        $header->contextheader = $this->context_header();
        $header->hasnavbar = empty($PAGE->layout_options['nonavbar']);
        $header->navbar = $this->navbar();
        if ($this->page->pagelayout != "mydashboard") {
            $header->pageheadingbutton = $this->create_course_button();
            $header->pageheadingbutton .= $this->course_menu();
            $header->pageheadingbutton .= $this->page_heading_button();
        }
        $header->courseheader = $this->course_header();
        $header->courseheader .= $this->scroll_header();

        return $this->render_from_template('theme_unige/full_header', $header);
    }

    /**
     * Get the navbar navigation menu.
     *
     * @return string HTML to display the navbar navigation menu.
     */
    public function navbar_navigation_menu() {
        $html = "";

        // If the user is logged in
        if (isloggedin()) {
            // List of urls
            $url_list = get_config('theme_unige', 'navigation_menu');
            $url_list_filter = preg_replace("/\r\n|\n\r/", '', trim($url_list));
            $url_array = explode(";", $url_list_filter);

            // Navigation menu for normal screens
            $html = html_writer::start_tag('div', array('class' => 'navbar-navigation-menu'));

            foreach ($url_array as $key => $value) {
                if ($value != NULL) {
                    $html .= html_writer::start_tag('a', array('href' => new moodle_url($value), 'class' => 'navbar-hover-effect'));
                    $html .= get_string('navbar-navigation-menu-link-' . ($key + 1), 'theme_unige');
                    $html .= html_writer::end_tag('a');
                }
            }

            $html .= html_writer::end_tag('div');

            // Navigation menu for small screens
            $html .= html_writer::start_tag('div', array('class'=>'navbar-navigation-menu-small action-menu'));
            $html .= html_writer::start_tag('div', array('class'=>'dropdown d-inline'));

            $html .= html_writer::start_tag('i', array('class' => 'icon fa fa-bars fa-fw', 'data-toggle' => 'dropdown'));
            $html .= html_writer::end_tag('i');

            $html .= html_writer::start_tag('div', array('class'=>'dropdown-menu dropdown-menu-right menu align-tr-br'));

            foreach ($url_array as $key => $value) {
                if ($value != NULL) {
                    $html .= html_writer::start_tag('a', array('href' => new moodle_url($value), 'class' => 'dropdown-item menu-action'));
                    $html .= html_writer::start_tag('span', array('class'=>'menu-action-text'));
                    $html .= get_string('navbar-navigation-menu-link-' . ($key + 1), 'theme_unige');
                    $html .= html_writer::end_tag('span');
                    $html .= html_writer::end_tag('a');
                }
            }

            $html .= html_writer::end_tag('div');
            $html .= html_writer::end_tag('div');
            $html .= html_writer::end_tag('div');
        }

        return $html;
    }

    /**
     * Get the navbar redirection menu.
     *
     * @return string HTML to display the navbar redirection menu.
     */
    public function navbar_redirection_menu() {
        // List of urls
        $url_list = get_config('theme_unige', 'redirection_menu');
        $url_list_filter = preg_replace("/\r\n|\n\r/", '', trim($url_list));
        $url_array = explode(";", $url_list_filter);

        $html = html_writer::start_tag('div', array('class' => 'navbar-redirection-menu navbar-hover-effect'));

        // Moodle unige logo
        $html .= html_writer::start_tag('a', array('href' => new moodle_url('/')));
        $html .= html_writer::start_tag('div', array('class' => 'moodle-unige-logo'));
        $html .= html_writer::div('', 'square');
        $html .= html_writer::end_tag('div');
        $html .= html_writer::end_tag('a');

        // Redirection submenu
        $html .= html_writer::start_tag('div', array('class'=>'redirection-submenu'));

        foreach ($url_array as $key => $value) {
            if ($value != NULL) {
                $html .= html_writer::start_tag('a', array('href' => $value, 'target' => "_blank"));
                $html .= get_string('navbar-redirection-menu-link-' . ($key + 1), 'theme_unige');
                $html .= html_writer::end_tag('a');
            }
        }

        $html .= html_writer::end_tag('div');
        $html .= html_writer::end_tag('div');

        return $html;
    }

    /**
     * Renders the header bar.
     *
     * @param context_header $contextheader Header bar object.
     * @return string HTML for the header bar.
     */
    protected function render_context_header(context_header $contextheader) {

        // All the html stuff goes here.
        $html = html_writer::start_div('page-context-header');

        // Image data.
        if (isset($contextheader->imagedata) AND $this->page->pagelayout == "mypublic") {
            // Header specific image.
            $html .= html_writer::div($contextheader->imagedata, 'page-header-image');
        }

        $heading = "";

        // Page title.
        // overide Page title for specific pages
        switch ($this->page->pagelayout) {
            case 'mydashboard':
                $heading = get_string('my-courses', 'theme_unige');
                break;

            case 'coursecategory':
                $heading = get_string('course-catalogue', 'theme_unige');
                break;

            case 'standard':
                if ($this->page->pagetype == "calendar-view"
                    OR $this->page->pagetype == "calendar-export"
                    OR $this->page->pagetype == "calendar-managesubscriptions") {
                    $heading = get_string('calendar', 'calendar');
                } elseif ($this->page->pagetype == "message-index") {
                    $heading = get_string('messages', 'message');
                } elseif ($this->page->pagetype == "grade-report-overview-index") {
                    $heading = get_string('grades', 'moodle');
                } elseif ($this->page->pagetype == "badges-mybadges"
                    OR $this->page->pagetype == "badges-preferences"
                    OR $this->page->pagetype == "badges-mybackpack") {
                    $heading = get_string('preferences', 'moodle');
                } elseif ($this->page->pagetype == "course-search"){
                    $heading = get_string('searchcourses', 'moodle');
                }
                break;

            case 'admin':

                if ($this->page->pagetype == "user-preferences"
                    OR $this->page->pagetype == "user-edit"
                    OR $this->page->pagetype == "user-editadvanced"
                    OR $this->page->pagetype == "login-change_password"
                    OR $this->page->pagetype == "user-language"
                    OR $this->page->pagetype == "user-forum"
                    OR $this->page->pagetype == "user-editor"
                    OR $this->page->pagetype == "user-course"
                    OR $this->page->pagetype == "user-calendar"
                    OR $this->page->pagetype == "message-edit"
                    OR $this->page->pagetype == "message-notificationpreferences"
                    OR $this->page->pagetype == "admin-roles-usersroles"
                    OR $this->page->pagetype == "admin-roles-permissions"
                    OR $this->page->pagetype == "admin-roles-check"
                    OR $this->page->pagetype == "admin-roles-check"
                    OR $this->page->pagetype == "badges-mybadges"
                    OR $this->page->pagetype == "badges-preferences"
                    OR $this->page->pagetype == "badges-mybackpack"
                    OR $this->page->pagetype == "blog-preferences"
                    OR $this->page->pagetype == "blog-external_blogs"
                    OR $this->page->pagetype == "blog-external_blog_edit") {
                    $heading = get_string('preferences', 'moodle');
                } elseif ($this->page->pagetype == "message-output-popup-notifications") {
                    $heading = get_string('notifications', 'moodle');
                } elseif (($this->page->pagetype == "course-edit" AND isset($_GET["category"])) OR ($this->page->pagetype == "course-edit" AND !isset($_REQUEST["id"])) )  {
                    // if category is set or if Request does not return a course id then its a new course creation
                    $heading = get_string('createnewcourse', 'moodle');
                } elseif ($this->page->pagetype == "course-edit" AND isset($_GET["id"])) {
                    // if id is set then its an edition and not a creation
                    $heading = get_string('editcoursesettings', 'moodle');
                }
                break;

            default:
                $heading = "";
                break;
        }

        // Headings.
        if ($heading != NULL) {
            $headings = $this->heading($heading, $contextheader->headinglevel);
        } else if (!isset($contextheader->heading)) {
            $headings = $this->heading($this->page->heading, $contextheader->headinglevel);
        } else {
            $headings = $this->heading($contextheader->heading, $contextheader->headinglevel);
        }

        $html .= html_writer::tag('div', $headings, array('class' => 'page-header-headings'));

        // Buttons.
        if (isset($contextheader->additionalbuttons)) {
            $html .= html_writer::start_div('btn-group header-button-group');
            foreach ($contextheader->additionalbuttons as $button) {
                if (!isset($button->page)) {
                    // Include js for messaging.
                    if ($button['buttontype'] === 'togglecontact') {
                        \core_message\helper::togglecontact_requirejs();
                    }
                    $image = $this->pix_icon($button['formattedimage'], $button['title'], 'moodle', array(
                        'class' => 'iconsmall',
                        'role' => 'presentation'
                    ));
                    $image .= html_writer::span($button['title'], 'header-button-title');
                } else {
                    $image = html_writer::empty_tag('img', array(
                        'src' => $button['formattedimage'],
                        'role' => 'presentation'
                    ));
                }
                $html .= html_writer::link($button['url'], html_writer::tag('span', $image), $button['linkattributes']);
            }
            $html .= html_writer::end_div();
        }
        $html .= html_writer::end_div();

        return $html;
    }

    /**
     * Construct a user menu, returning HTML that can be echoed out by a
     * layout file.
     *
     * @param stdClass $user A user object, usually $USER.
     * @param bool $withlinks true if a dropdown should be built.
     * @return string HTML fragment.
     */
    public function user_menu($user = null, $withlinks = null) {
        global $USER, $CFG;
        require_once($CFG->dirroot . '/user/lib.php');

        if (is_null($user)) {
            $user = $USER;
        }

        // Note: this behaviour is intended to match that of core_renderer::login_info,
        // but should not be considered to be good practice; layout options are
        // intended to be theme-specific. Please don't copy this snippet anywhere else.
        if (is_null($withlinks)) {
            $withlinks = empty($this->page->layout_options['nologinlinks']);
        }

        // Add a class for when $withlinks is false.
        $usermenuclasses = 'usermenu';
        if (!$withlinks) {
            $usermenuclasses .= ' withoutlinks';
        }

        $returnstr = "";

        // If during initial install, return the empty return string.
        if (during_initial_install()) {
            return $returnstr;
        }

        $loginpage = $this->is_login_page();
        $loginurl = get_login_url();
        $html = "";
        // If not logged in, show the typical not-logged-in string.
        if (!isloggedin() OR isguestuser()) {
            if (!$loginpage) {
                $html .= html_writer::start_tag('div', array('class'=>'navbar-login'));

                $html .= html_writer::start_tag('a', array('href' => $loginurl, 'class' => 'login-button'));
                $html .= get_string('login', 'moodle');
                $html .= html_writer::end_tag('a');

                $html .= html_writer::start_tag('div', array('class'=>'login-menu'));

                $html .= html_writer::start_tag('div', array('class'=>'login-arrow'));
                $html .= html_writer::end_tag('div');

                $html .= html_writer::start_tag('div', array('class'=>'login-submenu'));

                $html .= html_writer::start_tag('a', array('href'=>$CFG->wwwroot.'/Shibboleth.sso/Login?entityID=https://idp.unige.ch/idp/shibboleth&target='.$CFG->wwwroot.'/auth/shibboleth/index.php'));
                $html .= get_string('UNIGE-account', 'theme_unige');
                $html .= html_writer::end_tag('a');

                $html .= html_writer::start_tag('a', array('href'=>$CFG->wwwroot.'/Shibboleth.sso/Login?SAMLDS=1&entityID=https://aai.hcuge.ch/idp/shibboleth&target=https://moodle.unige.ch/auth/shibboleth/index.php'));
                $html .= get_string('HUG-account', 'theme_unige');
                $html .= html_writer::end_tag('a');

                $html .= html_writer::start_tag('a', array('href'=>$CFG->wwwroot.'/Shibboleth.sso/Login?SAMLDS=1&entityID=https://aai-logon.vho-switchaai.ch/idp/shibboleth&target=https://moodle.unige.ch/auth/shibboleth/index.php'));
                $html .= get_string('VHO-account', 'theme_unige');
                $html .= html_writer::end_tag('a');

                $html .= html_writer::start_tag('a', array('href'=>'https://moodle.unige.ch/auth/shibboleth/index.php'));
                $html .= get_string('other-swiss-universities-account', 'theme_unige');
                $html .= html_writer::end_tag('a');

                $html .= html_writer::end_tag('div');

                $html .= html_writer::end_tag('div');

                $html .= html_writer::end_tag('div');
            }
            return $html;
        }

        // Get some navigation opts.
        $opts = user_get_user_navigation_info_bis($user, $this->page);

        $avatarclasses = "avatars";
        $avatarcontents = html_writer::span($opts->metadata['useravatar'], 'avatar current');
        $usertextcontents = $opts->metadata['userfullname'];

        // Other user.
        if (!empty($opts->metadata['asotheruser'])) {
            $avatarcontents .= html_writer::span(
                $opts->metadata['realuseravatar'],
                'avatar realuser'
            );
            $usertextcontents = $opts->metadata['realuserfullname'];
            $usertextcontents .= html_writer::tag(
                'span',
                get_string(
                    'loggedinas',
                    'moodle',
                    html_writer::span(
                        $opts->metadata['userfullname'],
                        'value'
                    )
                ),
                array('class' => 'meta viewingas')
            );
        }

        // Role.
        if (!empty($opts->metadata['asotherrole'])) {
            $role = core_text::strtolower(preg_replace('#[ ]+#', '-', trim($opts->metadata['rolename'])));
            $usertextcontents .= html_writer::span(
                $opts->metadata['rolename'],
                'meta role role-' . $role
            );
        }

        // User login failures.
        if (!empty($opts->metadata['userloginfail'])) {
            $usertextcontents .= html_writer::span(
                $opts->metadata['userloginfail'],
                'meta loginfailures'
            );
        }

        // MNet.
        if (!empty($opts->metadata['asmnetuser'])) {
            $mnet = strtolower(preg_replace('#[ ]+#', '-', trim($opts->metadata['mnetidprovidername'])));
            $usertextcontents .= html_writer::span(
                $opts->metadata['mnetidprovidername'],
                'meta mnet mnet-' . $mnet
            );
        }

        $returnstr .= html_writer::span(
            html_writer::span($usertextcontents, 'usertext mr-1') .
            html_writer::span($avatarcontents, $avatarclasses),
            'userbutton'
        );

        // Create a divider (well, a filler).
        $divider = new action_menu_filler();
        $divider->primary = false;

        $am = new action_menu();
        $am->set_menu_trigger(
            $returnstr
        );
        $am->set_alignment(action_menu::TR, action_menu::BR);
        $am->set_nowrap_on_items();
        if ($withlinks) {
            $navitemcount = count($opts->navitems);
            $idx = 0;
            foreach ($opts->navitems as $key => $value) {

                switch ($value->itemtype) {
                    case 'divider':
                        // If the nav item is a divider, add one and skip link processing.
                        $am->add($divider);
                        break;

                    case 'invalid':
                        // Silently skip invalid entries (should we post a notification?).
                        break;

                    case 'link':
                        // Process this as a link item.
                        $pix = null;
                        if (isset($value->pix) && !empty($value->pix)) {
                            $pix = new pix_icon($value->pix, $value->title, null, array('class' => 'iconsmall'));
                        } else if (isset($value->imgsrc) && !empty($value->imgsrc)) {
                            $value->title = html_writer::img(
                                    $value->imgsrc,
                                    $value->title,
                                    array('class' => 'iconsmall')
                                ) . $value->title;
                        }

                        $al = new action_menu_link_secondary(
                            $value->url,
                            $pix,
                            $value->title,
                            array('class' => 'icon')
                        );
                        if (!empty($value->titleidentifier)) {
                            $al->attributes['data-title'] = $value->titleidentifier;
                        }
                        $am->add($al);
                        break;
                }

                $idx++;

                // Add dividers after the first item and before the last item.
                if ($idx == 1 || $idx == $navitemcount - 1) {
                    $am->add($divider);
                }
            }
        }

        return html_writer::div(
            $this->render($am),
            $usermenuclasses
        );
    }

    /**
     * Get the button "Create a course"
     *
     * @return string
     */
    public function create_course_button() {
        global $CFG;
        $html = "";
        $context = context_system::instance();

        // If the page is "My courses" or "Course catalogue" and the user has the capability to create a course
        if (has_capability('moodle/course:create', $context) AND ($this->page->pagelayout == "mydashboard" OR $this->page->pagelayout == "coursecategory" OR $this->page->pagetype == "course-search")) {

            // Define the category ID
            if ($this->page->pagelayout == "coursecategory" AND isset($_GET['categoryid'])) {
                $id_category = htmlspecialchars($_GET['categoryid']);
            } else {
                $id_category = $CFG->defaultrequestcategory;
            }

            // Create the button
            $html .= html_writer::start_tag('a', array('href'=> new moodle_url('/course/edit.php', array('category' => $id_category)), 'class'=>'btn btn-primary singlebutton'));
            $html .= html_writer::tag('i', null, array('class'=> 'fa fa-plus fa-fw'));
            $html .= " " . get_string('createnewcourse', 'moodle');
            $html .= html_writer::end_tag('a');
        }

        return $html;
    }

    /**
     * Get the course menu.
     *
     * @return string
     */

    public function course_menu() {
        global $PAGE, $CFG;
        $html = "";
        $context = context_course::instance($this->page->course->id);

        // If the page is a course page
        if (($this->page->pagelayout == "course") OR ($this->page->course->format == "singleactivity" AND $this->page->pagelayout == "incourse")) {
            if ($this->page->course->format != "singleactivity" AND $this->page->course->format != "social") {
                $html .= html_writer::start_tag('select', array('id' => 'select-topics-1', 'class' => 'custom-select', "onchange" => "window.location.href='#' + document.getElementById('select-topics-1').value; document.getElementById('select-topics-1').value = ''"));
                $html .= html_writer::tag('option', get_string('course-topics', 'theme_unige'), array('value' => '', 'selected' => 'selected'));

                $course_modinfo = get_fast_modinfo($this->page->course->id);
                $course_sections = $course_modinfo->get_section_info_all();


                // Course topics list
                $counter = 0;
                $format = course_get_format($this->page->course);

                foreach ($course_sections as $num_section) {
                    if ($counter != 0) {

                        // If the section is visible to students
                        if ((($course_sections[$counter]->visible == 0) AND (has_capability('moodle/course:create', $context))) OR ($course_sections[$counter]->visible == 1)) {

                                $sectionname = $format->get_section_name($num_section);
                                $html .= html_writer::tag('option', $sectionname, array('value' => 'section-' . $counter));
                        }
                    }
                    $counter += 1;
                } //end topic list

                $html .= html_writer::end_tag('select');
            }

            // Menu with "participants" and "grades" buttons
            $html .= html_writer::start_tag('div', array('class'=>'btn-group'));

            $html .= html_writer::start_tag('a', array('href'=> new moodle_url('/user/index.php', array('id' => $this->page->course->id)), 'class'=>'btn btn-secondary singlebutton'));
            $html .= get_string('participants', 'moodle');
            $html .= html_writer::end_tag('a');

            //choose url to link to the "grade" button according to user profile
            $studentgradereport = '/grade/report/user/index.php';
            $profgradereport = '/grade/report/grader/index.php';
            //set to student grade report by default.
            $urlgradereport = $studentgradereport;
            // if user has capability to update this course, then use prof url
            if(has_capability('moodle/course:update', $context)){
                $urlgradereport = $profgradereport;
            }

            $html .= html_writer::start_tag('a', array('href'=> new moodle_url($urlgradereport, array('id' => $this->page->course->id)), 'class'=>'btn btn-secondary singlebutton'));
            $html .= get_string('grades', 'moodle');
            $html .= html_writer::end_tag('a');

            $html .= html_writer::end_tag('div');

            // If edit mode is enabled
            if ($PAGE->user_is_editing()) {
                $html .= html_writer::start_tag('a', array('href'=> new moodle_url('/course/view.php?bui_addblock', array('id' => $this->page->course->id, 'sesskey' => sesskey())), 'class'=>'btn btn-secondary add-block-button', 'data-key'=>'addblock', 'data-isexpandable'=>'0', 'data-indent'=>'0', 'data-showdivider'=>'1', 'data-type'=>'60', 'data-nodetype'=>'0', 'data-collapse'=>'0', 'data-forceopen'=>'0', 'data-isactive'=>'0', 'data-hidden'=>'0', 'data-preceedwithhr'=>'0'));
                $html .= get_string('addblock', 'moodle');
                $html .= html_writer::end_tag('a');
            }
        }

        return $html;
    }

    /**
     * Get the edit mode button for course page
     *
     * @return string
     */
    public function course_edit_mode_button() {
        global $PAGE;
        $html = "";

        // If the page is a course page
        if (($this->page->pagelayout == "course") OR ($this->page->course->format == "singleactivity" AND $this->page->pagelayout == "incourse")) {
            $context = context_course::instance($this->page->course->id);

            // If the user has the capability to create a course
            if (has_capability('moodle/course:update', $context)) {

                // If edit mode is enabled
                if ($PAGE->user_is_editing()) {
                    $html .= html_writer::start_tag('a', array('href'=> new moodle_url('/course/view.php', array('id' => $this->page->course->id, 'sesskey' => sesskey(), 'edit' => 'off')), 'class'=>'btn btn-primary singlebutton course-edit-mode-button'));
                    $html .= html_writer::tag('i', null, array('class'=> 'fa fa-times fa-fw'));
                    $html .= " " . get_string('turneditingoff', 'moodle');
                    $html .= html_writer::end_tag('a');
                } else {
                    $html .= html_writer::start_tag('a', array('href'=> new moodle_url('/course/view.php', array('id' => $this->page->course->id, 'sesskey' => sesskey(), 'edit' => 'on')), 'class'=>'btn btn-primary singlebutton course-edit-mode-button'));
                    $html .= html_writer::tag('i', null, array('class'=> 'fa fa-pencil fa-fw'));
                    $html .= " " . get_string('turneditingon', 'moodle');
                    $html .= html_writer::end_tag('a');
                }
            }
        }

        return $html;
    }

    /**
     * Get the full header displayed on scroll
     *
     * @return string
     */
    public function scroll_header() {
        global $PAGE;
        $html = "";

        // If the page is a course page
        if (($this->page->pagelayout == "course") OR ($this->page->course->format == "singleactivity" AND $this->page->pagelayout == "incourse")) {
            $html .= html_writer::start_tag('div', array('id'=>'scroll-header'));

            $html .= html_writer::start_div('card');

            $html .= html_writer::start_tag('p', array('class'=>'course-name'));
            $html .= $this->page->course->fullname;
            $html .= html_writer::end_tag('p');

            $html .= html_writer::start_div('ml-auto scroll-header-buttons');
            $html .= $this->course_edit_mode_button();

            // If the course is not a "singleactivity"
            if ($this->page->course->format != "singleactivity" AND $this->page->course->format != "social") {
                $html .= html_writer::start_tag('select', array('id' => 'select-topics-2', 'class'=>'course-menu-navigation-topics custom-select', "onchange" => "window.location.href='#' + document.getElementById('select-topics-2').value; document.getElementById('select-topics-2').value = ''"));
                $html .= html_writer::tag('option', get_string('course-topics', 'theme_unige'), array('value' => '', 'selected'=>'selected'));

                $course_modinfo = get_fast_modinfo($this->page->course->id);
                $course_sections = $course_modinfo->get_section_info_all();

                // Course topics list
                $counter = 0;
                foreach ($course_sections as $num_section) {
                    if ($counter != 0) {

                        // If the section is visible to students
                        $context = context_course::instance($this->page->course->id);
                        if ((($course_sections[$counter]->visible == 0) AND (has_capability('moodle/course:create', $context))) OR ($course_sections[$counter]->visible == 1)) {

                            // If the section has a name
                            if (isset($course_sections[$counter]->name)) {
                                $html .= html_writer::tag('option', $course_sections[$counter]->name, array('value' => 'section-' . $counter));
                            } else {
                                $html .= html_writer::tag('option', get_string('topic', 'moodle') . ' ' . $counter, array('value' => 'section-' . $counter));
                            }
                        }
                    }
                    $counter += 1;
                }

                $html .= html_writer::end_tag('select');
            }

            $html .= html_writer::end_div();
            $html .= html_writer::end_div();
            $html .= html_writer::end_div();
        }

        return $html;
    }


    /**
     * Get the footer html
     *
     * @return string
     */

    public function footer_html() {
        // Left column
        $html = html_writer::start_tag('div', array('class'=>'footer-column'));
        $html .= html_writer::start_tag('p', array('class'=>'footer-column-titre'));
        $html .= get_string('footer-column-left-title', 'theme_unige');
        $html .= html_writer::end_tag('p');
        $html .= html_writer::start_tag('ul');

        $url_list = get_config('theme_unige', 'footer_column_left');
        $url_list_filter = preg_replace("/\r\n|\n\r/", '', trim($url_list));
        $url_array = explode(";", $url_list_filter);

        foreach ($url_array as $key => $value) {
            if ($value != NULL) {
                $html .= html_writer::start_tag('a', array('href' => $value, 'target' => "_blank"));
                $html .= html_writer::start_tag('li', array('href' => $value));
                $html .= get_string('footer-column-left-link-' . ($key + 1), 'theme_unige');
                $html .= html_writer::end_tag('li');
                $html .= html_writer::end_tag('a');
            }
        }

        $html .= html_writer::end_tag('ul');
        $html .= html_writer::end_tag('div');

        // Middle column
        $html .= html_writer::start_tag('div', array('class'=>'footer-column footer-column-middle'));

        $column_middle_display = get_config('theme_unige', 'footer_column_middle_display');

        if ($column_middle_display == true) {

            $html .= html_writer::start_tag('p', array('class'=>'footer-column-titre'));
            $html .= get_string('footer-column-middle-title', 'theme_unige');
            $html .= html_writer::end_tag('p');
            $html .= html_writer::start_tag('ul');

            $url_list = get_config('theme_unige', 'footer_column_middle');
            $url_list_filter = preg_replace("/\r\n|\n\r/", '', trim($url_list));
            $url_array = explode(";", $url_list_filter);

            foreach ($url_array as $key => $value) {
                if ($value != NULL) {
                    $html .= html_writer::start_tag('a', array('href' => $value, 'target' => "_blank"));
                    $html .= html_writer::start_tag('li', array('href' => $value));
                    $html .= get_string('footer-column-middle-link-' . ($key + 1), 'theme_unige');
                    $html .= html_writer::end_tag('li');
                    $html .= html_writer::end_tag('a');
                }
            }
            $html .= html_writer::end_tag('ul');
        }

        $html .= html_writer::end_tag('div');

        // Right column
        $html .= html_writer::start_tag('div', array('class'=>'footer-column'));
        $html .= html_writer::start_tag('p', array('class'=>'footer-column-titre'));
        $html .= get_string('footer-column-right-title', 'theme_unige');
        $html .= html_writer::end_tag('p');

        $url = get_config('theme_unige', 'footer_column_right_app_ios_url');
        $url_filter = preg_replace("/\r\n|\n\r/", '', trim($url));

        $html .= html_writer::start_tag('a', array('href' => $url_filter, 'target' => "_blank"));
        $html .= html_writer::start_tag('div', array('class'=>'store-logo-div app-store-logo-div'));
        $html .= html_writer::end_tag('div');
        $html .= html_writer::end_tag('a');

        $url = get_config('theme_unige', 'footer_column_right_app_android_url');
        $url_filter = preg_replace("/\r\n|\n\r/", '', trim($url));

        $html .= html_writer::start_tag('a', array('href' => $url_filter, 'target' => "_blank"));
        $html .= html_writer::start_tag('div', array('class'=>'store-logo-div play-store-logo-div'));
        $html .= html_writer::end_tag('div');
        $html .= html_writer::end_tag('a');

        $html .= html_writer::end_tag('div');

        return $html;
    }

    /**
     * This is an optional menu that can be added to a layout by a theme. It contains the
     * menu for the most specific thing from the settings block. E.g. Module administration.
     *
     * @return string
     */
    public function region_main_settings_menu() {
        $context = $this->page->context;
        $menu = new action_menu();

        if ($context->contextlevel == CONTEXT_MODULE) {

            $this->page->navigation->initialise();
            $node = $this->page->navigation->find_active_node();
            $buildmenu = true;
            // If the settings menu has been forced then show the menu.
            if ($this->page->is_settings_menu_forced()) {
                $buildmenu = true;
            } else if (!empty($node) && ($node->type == navigation_node::TYPE_ACTIVITY ||
                    $node->type == navigation_node::TYPE_RESOURCE)) {

                $items = $this->page->navbar->get_items();
                $navbarnode = end($items);
                // We only want to show the menu on the first page of the activity. This means
                // the breadcrumb has no additional nodes.
                if ($navbarnode && ($navbarnode->key === $node->key && $navbarnode->type == $node->type)) {
                    $buildmenu = true;
                }
            }
            if ($buildmenu) {
                // Get the course admin node from the settings navigation.
                $node = $this->page->settingsnav->find('modulesettings', navigation_node::TYPE_SETTING);
                if ($node) {
                    // Build an action menu based on the visible nodes from this navigation tree.
                    $this->build_action_menu_from_navigation($menu, $node);
                }
            }

        } else if ($context->contextlevel == CONTEXT_COURSECAT) {
            // For course category context, show category settings menu, if we're on the course category page.
            if ($this->page->pagetype === 'course-index-category') {
                $node = $this->page->settingsnav->find('categorysettings', navigation_node::TYPE_CONTAINER);
                if ($node) {
                    // Build an action menu based on the visible nodes from this navigation tree.
                    $this->build_action_menu_from_navigation($menu, $node);
                }
            }

        } else {
            $items = $this->page->navbar->get_items();
            $navbarnode = end($items);

            if ($navbarnode && ($navbarnode->key === 'participants')) {
                $node = $this->page->settingsnav->find('users', navigation_node::TYPE_CONTAINER);
                if ($node) {
                    // Build an action menu based on the visible nodes from this navigation tree.
                    $this->build_action_menu_from_navigation($menu, $node);
                }

            }
        }
        return $this->render($menu);
    }

    /**
     * Get the button "Add a block" for "My courses" page
     *
     * @return string
     */
    public function add_block_button_my_courses() {
        global $PAGE;
        $html = "";

        // If the page is "My courses"
        if ($this->page->pagetype == "my-index" AND $this->page->pagelayout == "mydashboard") {

            // If the user has the capability to create a course
            $context = context_system::instance();
            if (has_capability('moodle/course:create', $context)) {

                // If edit mode is enabled
                if ($PAGE->user_is_editing()) {
                    $html .= html_writer::start_tag('a', array('href' => new moodle_url('/theme/index.php?bui_addblock', array('sesskey' => sesskey())), 'class' => 'singlebutton btn btn-secondary add-block-button', 'data-key' => 'addblock', 'data-isexpandable' => '0', 'data-indent' => '0', 'data-showdivider' => '1', 'data-type' => '60', 'data-nodetype' => '0', 'data-collapse' => '0', 'data-forceopen' => '0', 'data-isactive' => '0', 'data-hidden' => '0', 'data-preceedwithhr' => '0'));
                    $html .= " " . get_string('addblock', 'moodle');
                    $html .= html_writer::end_tag('a');
                }
            }
        }
        return $html;
    }

    /**
     * Get the button "Add a block" for "index" page for admin users
     *
     * @return string
     */
    public function add_block_button_index_admin() {
        global $PAGE;
        $html = "";

        // If the page is "Index"
        if ($this->page->pagetype == "site-index") {

            // If the user is admin
            if (is_siteadmin()) {

                // If edit mode is enabled
                if ($PAGE->user_is_editing()) {
                    $html .= html_writer::start_tag('a', array('href' => new moodle_url('/theme/index.php?bui_addblock', array('sesskey' => sesskey())), 'class' => 'singlebutton btn btn-secondary add-block-button-index', 'data-key' => 'addblock', 'data-isexpandable' => '0', 'data-indent' => '0', 'data-showdivider' => '1', 'data-type' => '60', 'data-nodetype' => '0', 'data-collapse' => '0', 'data-forceopen' => '0', 'data-isactive' => '0', 'data-hidden' => '0', 'data-preceedwithhr' => '0'));
                    $html .= " " . get_string('addblock', 'moodle');
                    $html .= html_writer::end_tag('a');
                }
            }
        }
        return $html;
    }

    /**
     * Return the navbar content so that it can be echoed out by the layout
     *
     * @return string XHTML navbar
     */
    public function navbar() {
        $items = $this->page->navbar->get_items();

        $html = html_writer::start_tag('nav', array('role'=>'navigation'));
        $html .= html_writer::start_tag('ol', array('class'=>'breadcrumb'));

        $counter = 0;
        foreach ($items as $item) {
            // Conditions to cut the navbar
            if (($counter > 0 AND (($this->page->pagelayout == "coursecategory" OR $this->page->pagelayout == "admin" OR $this->page->pagelayout == "standard" OR $this->page->pagelayout == "mypublic") AND ($this->page->pagetype != "calendar-view" AND $this->page->pagetype != "calendar-managesubscriptions" AND $this->page->pagetype != "course-edit")))
                OR (($counter > 1 AND ($this->page->pagelayout == "course" OR $this->page->pagelayout == "incourse" OR $this->page->pagelayout == "report" OR $this->page->pagetype == "calendar-view" OR $this->page->pagetype == "calendar-managesubscriptions" OR $this->page->pagetype == "course-edit")))) {
                // If the item is not clickable
                if ($item->action == null) {
                    $html .= html_writer::start_tag('li', array('class'=>'breadcrumb-item'));
                    $html .= $item->text;
                    $html .= html_writer::end_tag('li');
                } else {
                    $html .= html_writer::start_tag('li', array('class'=>'breadcrumb-item'));
                    $html .= html_writer::start_tag('a', array('href'=> $item->action, 'title' => $item->key));
                    $html .= $item->text;
                    $html .= html_writer::end_tag('a');
                    $html .= html_writer::end_tag('li');
                }
            }
            $counter += 1;
        }

        $html .= html_writer::end_tag('ol');
        $html .= html_writer::end_tag('nav');

        return $html;
    }
}
